@@ -1,6 +1,6 @@
 import csv
 
-from models import Row
+from .models import Row
 
 def get_processed_rows(filepath:str) -> list[Row]:
     i = 0
